summaryrefslogtreecommitdiff
path: root/ace/Asynch_Acceptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'ace/Asynch_Acceptor.h')
-rw-r--r--ace/Asynch_Acceptor.h10
1 files changed, 3 insertions, 7 deletions
diff --git a/ace/Asynch_Acceptor.h b/ace/Asynch_Acceptor.h
index e8cb490794d..27efe871c0f 100644
--- a/ace/Asynch_Acceptor.h
+++ b/ace/Asynch_Acceptor.h
@@ -26,8 +26,6 @@
#include "ace/Default_Constants.h"
#include "ace/Asynch_IO.h"
-ACE_BEGIN_VERSIONED_NAMESPACE_DECL
-
// Forward declarations
class ACE_Message_Block;
class ACE_INET_Addr;
@@ -72,7 +70,7 @@ public:
* associated @c ACE_Service_Handler::addresses() method
* after any call to @c validate_new_connection() and prior
* to the @c open() hook method call.
* @param backlog Optional, defaulting to @c ACE_DEFAULT_ASYNCH_BACKLOG (which
* can be adjusted in your platform's @c config.h file).
* Specifies the listening backlog for the listening socket.
* @param reuse_addr Optional, indicates whether the @c SO_REUSEADDR
@@ -109,7 +107,7 @@ public:
virtual int open (const ACE_INET_Addr &address,
size_t bytes_to_read = 0,
int pass_addresses = 0,
- int backlog = ACE_DEFAULT_ASYNCH_BACKLOG,
+ int backlog = ACE_DEFAULT_BACKLOG,
int reuse_addr = 1,
ACE_Proactor *proactor = 0,
int validate_new_connection = 0,
@@ -125,7 +123,7 @@ public:
* closed and the all outstanding asynchronous operations have
* either completed or have been canceled on the old listen handle.
*/
- virtual int set_handle (ACE_HANDLE handle);
+ virtual void set_handle (ACE_HANDLE handle);
/// This initiates a new asynchronous accept operation.
/**
@@ -281,8 +279,6 @@ private:
int addr_family_;
};
-ACE_END_VERSIONED_NAMESPACE_DECL
-
#if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
#include "ace/Asynch_Acceptor.cpp"
#endif /* ACE_TEMPLATES_REQUIRE_SOURCE */
@@ -72,7 +70,7 @@ public:
* after any call to @c validate_new_connection() and prior
* to the @c open() hook method call.
- * @param backlog Optional, defaulting to @c ACE_DEFAULT_ASYNCH_BACKLOG (which
+ * @param backlog Optional, defaulting to @c ACE_DEFAULT_BACKLOG (which
* can be adjusted in your platform's @c config.h file).
* Specifies the listening backlog for the listening socket.